% THE KINETIC MODEL OF TEUSINK S. CEREVISIAE IN SDE FORMAT.

function [out1,out2,out3] = Mteusink_sdefile(t,x,flag,bigtheta,SDETYPE,NUMDEPVARS,NUMSIM)

% SDE model definition: drift, diffusion, derivatives and initial conditions.
%
% [out1,out2,out3] = M9_sdefile(t,x,flag,bigtheta,SDETYPE,NUMDEPVARS,NUMSIM)
%
% IN:     t; working value of independent variable (time)
%         x; working value of dependent variable 
%         flag; a switch, with values 'init' or otherwise
%         bigtheta; complete structural parameter vector
%         SDETYPE; the SDE definition: can be 'Ito' or 'Strat' (Stratonovich)
%         NUMDEPVARS; the number of dependent variables, i.e. the SDE dimension
%         NUMSIM; the number of desired simulations for the SDE numerical integration 
% OUT:    out1; in case of flag='init' is just the initial time, otherwise it is the (vector of) SDE drift(s)
%         out2; in case of flag='init' is the initial value of the dependent variables. Otherwise it is the SDE diffusion(s)
%         out3; in case of flag='init' it is nothing. Otherwise it is the SDE's partial derivative(s) of the diffusion term 

% Copyright (C) 2007, Umberto Picchini  
% umberto.picchini@biomatematica.it
% http://www.biomatematica.it/Pages/Picchini.html
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.
X    =    0   ;              
GLCo =    50  ;              
SUCC =    0  ;               
GLY  =    0.15 ;             
Trh  =    0  ;               
Glyc =    0  ;               
ETOH =    50 ;               
CO2  =    1 ;

VmGLT     =   97.264;    
KeqGLT    =   1;         
KmGLTGLCo =   1.1918;    
KmGLTGLCi =   1.1918;    
VmGLK     =   226.452;    
SUMAXP    =   4.1 ;       
KeqAK     =   0.45;       
KeqGLK    =   3800 ;      
KmGLKATP  =   0.15 ;      
KmGLKGLCi =   0.08 ;      
KmGLKG6P  =   30   ;      
KmGLKADP  =   0.23 ;      
VmPGI     =  339.677;    
KmPGIG6P  =  1.4  ;      
KeqPGI    =  0.314;      
KmPGIF6P  =  0.3  ;      
KGLYCOGEN =   6   ;      
KTREHALOSE=    2.4;       
gR       =    5.12;        
VmPFK    =    182.903 ;    
SUMAXP   =    4.1   ;      
KeqAK    =    0.45  ;      
KmPFKF6P =    0.1   ;      
KmPFKATP =    0.71  ;      
L0       =    0.66  ;      
CPFKF26BP=    0.0174;      
F26BP    =    0.02  ;      
KPFKF26BP=    0.000682 ;   
CPFKF16BP =   0.397 ;      
KPFKF16BP =   0.111 ;      
CPFKAMP   =   0.0845;      
KPFKAMP   =   0.0995;      
CiPFKATP  =   100   ;      
KiPFKATP  =   0.65  ;      
CPFKATP   =   3     ;      
VmALD     =   322.258 ;   
KeqTPI    =   0.045 ;     
KeqALD    =   0.069 ;     
KmALDF16P =   0.3   ;     
KmALDDHAP =   2.4 ;       
KmALDGAP  =   2   ;       
KmALDGAPi =   10  ;       
VmG3PDH   =     70.15 ;    
KeqG3PDH  =     4300  ;    
KeqTPI    =     0.045 ;    
KmG3PDHDHAP =   0.4   ;    
KmG3PDHNADH =   0.023 ;    
KmG3PDHNAD  =   0.93  ;    
KmG3PDHGLY  =   1     ;    
VmGAPDHr    =   6549.68;    
KmGAPDHBPG  =   0.0098 ;    
KmGAPDHNADH =   0.06   ;    
KeqTPI      =   0.045  ;    
VmGAPDHf    =   1184.52;    
KmGAPDHGAP  =   0.21   ;    
KmGAPDHNAD  =   0.09   ;    
VmPGK    =   1306.45   ; 
KeqPGK   =   3200    ;   
SUMAXP   =   4.1     ;   
KeqAK    =   0.45    ;   
KmPGKATP =   0.3     ;   
KmPGKP3G =   0.53    ;   
KmPGKADP =   0.2     ;   
KmPGKBPG =   0.003   ;   
VmPGM    =   2525.81 ;   
KmPGMP3G =   1.2   ;     
KeqPGM   =   0.19  ;     
KmPGMP2G =   0.08  ;     
VmENO    =   365.806 ;   
KmENOP2G =   0.04   ;    
KeqENO   =   6.7    ;    
KmENOPEP =   0.5    ;    
VmPYK    =   1088.71;    
KmPYKPEP =   0.14  ;     
KmPYKADP =   0.53  ;     
SUMAXP   =   4.1   ;     
KeqAK    =   0.45  ;     
KeqPYK   =   6500  ;     
KmPYKPYR =   21    ;     
KmPYKATP =   1.5   ;     
VmPDC    =   174.194    ;
nPDC     =   1.9    ;    
KmPDCPYR =   4.33   ;    
KSUCC   = 21.4     ; 
VmADH   =     810  ;       
KiADHNAD=     0.92 ;       
KmADHETOH =   17    ;      
KeqADH    =   6.9e-005  ;  
KmADHNAD  =   0.17   ;     
KmADHNADH =   0.11   ;     
KiADHNADH =   0.031  ;     
KmADHACE  =   1.11   ;     
KiADHACE  =   1.1    ;     
KiADHETOH =   90   ;       
KATPASE  =  39.5   ;   
KeqAK    =  0.45   ;   
SUMAXP   =  4.1  ; 

% Parameters
Xzero1 = bigtheta(1);  
Xzero2 = bigtheta(2);  
Xzero3 = bigtheta(3); 
Xzero4 = bigtheta(4); 
Xzero5 = bigtheta(5);  
Xzero6 = bigtheta(6);  
Xzero7 = bigtheta(7); 
Xzero8 = bigtheta(8); 
Xzero9 = bigtheta(9);  
Xzero10 = bigtheta(10);  
Xzero11 = bigtheta(11); 
Xzero12 = bigtheta(12); 
Xzero13 = bigtheta(13); 

sigma1 = bigtheta(14);
sigma2 = bigtheta(15);
sigma3 = bigtheta(16);
sigma4 = bigtheta(17);
sigma5 = bigtheta(18);
sigma6 = bigtheta(19);
sigma7 = bigtheta(20);
sigma8 = bigtheta(21);
sigma9 = bigtheta(22);
sigma10 = bigtheta(23);
sigma11 = bigtheta(24);
sigma12 = bigtheta(25);
sigma13 = bigtheta(26);

if nargin < 3 || isempty(flag)
    
   xsplitted  =  SDE_split_sdeinput(x,NUMDEPVARS);
   
  %::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::: 
  %::::::::::::::::::::::::::::::::::::::::::  DEFINE HERE THE SDE  ::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
  %:::::::::::::::::::::::: (define the initial conditions at the bottom of the page) ::::::::::::::::::::::::::::::::::::::::::::::::::::
  %:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::

  X1 = xsplitted{1}; % e.g. for a thre-dimensional SDE write X1 = xsplitted{1}; X2 = xsplitted{2}; X3 = xsplitted{3};
  X2 = xsplitted{2};
  X3 = xsplitted{3};
  X4 = xsplitted{4};
  X5 = xsplitted{5};
  X6 = xsplitted{6};
  X7 = xsplitted{7};
  X8 = xsplitted{8};
  X9 = xsplitted{9};
  X10 = xsplitted{10};
  X11 = xsplitted{11};
  X12 = xsplitted{12};
  X13 = xsplitted{13};
  CC14 =   1.59 - X13;  % NAD + NADH sum is constant.

   r1 = VmGLT*(GLCo-X1./KeqGLT)./(KmGLTGLCo*(1+GLCo./KmGLTGLCo+X1./KmGLTGLCi+0.91*GLCo.*X1./(KmGLTGLCi*KmGLTGLCo)));
   r2 = VmGLK*(-(X2.*(SUMAXP-power(power(SUMAXP,2)-2*SUMAXP.*X12+8*KeqAK.*SUMAXP.*X12+power(X12,2)-4*KeqAK.*power(X12,2),0.5))./((1-4*KeqAK).*KeqGLK))+X1.*(-SUMAXP+X12-4*KeqAK.*X12+power(power(SUMAXP,2)-2*SUMAXP*X12+8*KeqAK*SUMAXP.*X12+power(X12,2)-4*KeqAK*power(X12,2),0.5))./(2-8*KeqAK))./(KmGLKATP.*KmGLKGLCi.*(1+X2./KmGLKG6P+X1./KmGLKGLCi).*(1+(SUMAXP-power(power(SUMAXP,2)-2*SUMAXP.*X12+8*KeqAK.*SUMAXP.*X12+power(X12,2)-4*KeqAK*power(X12,2),0.5))./((1-4*KeqAK).*KmGLKADP)+(-SUMAXP+X12-4*KeqAK.*X12+power(power(SUMAXP,2)-2*SUMAXP.*X12+8*KeqAK*SUMAXP.*X12+power(X12,2)-4*KeqAK.*power(X12,2),0.5))./((2-8*KeqAK)*KmGLKATP)));
   r3 = VmPGI./KmPGIG6P.*(X2-X3./KeqPGI)./(1+X2./KmPGIG6P+X3./KmPGIF6P);
   r4 = KGLYCOGEN;
   r5 = KTREHALOSE;
   r6 = gR*VmPFK*X3.*(-SUMAXP+X12-4*KeqAK.*X12+power(power(SUMAXP,2)-2*SUMAXP.*X12+8.*KeqAK.*SUMAXP.*X12+power(X12,2)-4.*KeqAK.*power(X12,2),0.5)).*(1+X3./KmPFKF6P+(-SUMAXP+X12-4.*KeqAK.*X12+power(power(SUMAXP,2)-2.*SUMAXP.*X12+8.*KeqAK.*SUMAXP.*X12+power(X12,2)-4.*KeqAK.*power(X12,2),0.5))./((2-8.*KeqAK).*KmPFKATP)+gR.*X3.*(-SUMAXP+X12-4.*KeqAK.*X12+power(power(SUMAXP,2)-2.*SUMAXP.*X12+8.*KeqAK.*SUMAXP.*X12+power(X12,2)-4.*KeqAK.*power(X12,2),0.5))./((2-8.*KeqAK).*KmPFKATP.*KmPFKF6P))./((2-8.*KeqAK).*KmPFKATP.*KmPFKF6P.*(L0.*power(1+CPFKF26BP.*F26BP./KPFKF26BP+CPFKF16BP.*X4./KPFKF16BP,2).*power(1+2.*CPFKAMP.*KeqAK.*power(SUMAXP-power(power(SUMAXP,2)-2.*SUMAXP.*X12+8.*KeqAK.*SUMAXP.*X12+power(X12,2)-4.*KeqAK.*power(X12,2),0.5),2)./((-1+4.*KeqAK).*KPFKAMP.*(SUMAXP-X12+4.*KeqAK.*X12-power(power(SUMAXP,2)-2.*SUMAXP.*X12+8.*KeqAK.*SUMAXP.*X12+power(X12,2)-4.*KeqAK.*power(X12,2),0.5))),2).*power(1+CiPFKATP.*(-SUMAXP+X12-4.*KeqAK.*X12+power(power(SUMAXP,2)-2.*SUMAXP.*X12+8.*KeqAK.*SUMAXP.*X12+power(X12,2)-4.*KeqAK.*power(X12,2),0.5))./((2-8.*KeqAK).*KiPFKATP),2).*power(1+CPFKATP.*(-SUMAXP+X12-4.*KeqAK.*X12+power(power(SUMAXP,2)-2.*SUMAXP.*X12+8.*KeqAK.*SUMAXP.*X12+power(X12,2)-4.*KeqAK.*power(X12,2),0.5))./((2-8.*KeqAK).*KmPFKATP),2)./(power(1+F26BP./KPFKF26BP+X4./KPFKF16BP,2).*power(1+2.*KeqAK.*power(SUMAXP-power(power(SUMAXP,2)-2.*SUMAXP.*X12+8.*KeqAK.*SUMAXP.*X12+power(X12,2)-4.*KeqAK.*power(X12,2),0.5),2)./((-1+4.*KeqAK).*KPFKAMP.*(SUMAXP-X12+4.*KeqAK.*X12-power(power(SUMAXP,2)-2.*SUMAXP.*X12+8.*KeqAK.*SUMAXP.*X12+power(X12,2)-4.*KeqAK.*power(X12,2),0.5))),2).*power(1+(-SUMAXP+X12-4.*KeqAK.*X12+power(power(SUMAXP,2)-2.*SUMAXP.*X12+8.*KeqAK.*SUMAXP.*X12+power(X12,2)-4.*KeqAK.*power(X12,2),0.5))./((2-8.*KeqAK).*KiPFKATP),2))+power(1+X3./KmPFKF6P+(-SUMAXP+X12-4.*KeqAK.*X12+power(power(SUMAXP,2)-2.*SUMAXP.*X12+8.*KeqAK.*SUMAXP.*X12+power(X12,2)-4.*KeqAK.*power(X12,2),0.5))./((2-8.*KeqAK).*KmPFKATP)+gR.*X3.*(-SUMAXP+X12-4.*KeqAK.*X12+power(power(SUMAXP,2)-2.*SUMAXP.*X12+8.*KeqAK.*SUMAXP.*X12+power(X12,2)-4.*KeqAK.*power(X12,2),0.5))./((2-8.*KeqAK).*KmPFKATP.*KmPFKF6P),2)));
   r7 = VmALD.*(X4-KeqTPI*power(X5,2)./(KeqALD*power(1+KeqTPI,2)))./(KmALDF16P*(1+X4./KmALDF16P+X5./((1+KeqTPI).*KmALDDHAP)+KeqTPI*X5./((1+KeqTPI)*KmALDGAP)+KeqTPI*X4.*X5./((1+KeqTPI)*KmALDF16P*KmALDGAPi)+KeqTPI*power(X5,2)./(power(1+KeqTPI,2)*KmALDDHAP*KmALDGAP)));
   r8 = VmG3PDH.*(-(GLY.*CC14./KeqG3PDH)+X13.*X5./(1+KeqTPI))./(KmG3PDHDHAP*KmG3PDHNADH*(1+CC14./KmG3PDHNAD+X13./KmG3PDHNADH).*(1+GLY./KmG3PDHGLY+X5./((1+KeqTPI).*KmG3PDHDHAP)));
   r9 = (-(VmGAPDHr.*X6.*X13./(KmGAPDHBPG*KmGAPDHNADH))+KeqTPI*VmGAPDHf.*CC14.*X5./((1+KeqTPI)*KmGAPDHGAP*KmGAPDHNAD))./((1+CC14./KmGAPDHNAD+X13./KmGAPDHNADH).*(1+X6./KmGAPDHBPG+KeqTPI*X5./((1+KeqTPI)*KmGAPDHGAP)));
   r10 = VmPGK*(KeqPGK*X6.*(SUMAXP-power(power(SUMAXP,2)-2*SUMAXP*X12+8*KeqAK*SUMAXP*X12+power(X12,2)-4*KeqAK*power(X12,2),0.5))./(1-4*KeqAK)-(-SUMAXP+X12-4*KeqAK*X12+power(power(SUMAXP,2)-2*SUMAXP*X12+8*KeqAK*SUMAXP*X12+power(X12,2)-4*KeqAK*power(X12,2),0.5)).*X7./(2-8*KeqAK))./(KmPGKATP*KmPGKP3G*(1+(SUMAXP-power(power(SUMAXP,2)-2*SUMAXP*X12+8*KeqAK*SUMAXP*X12+power(X12,2)-4*KeqAK*power(X12,2),0.5))./((1-4*KeqAK)*KmPGKADP)+(-SUMAXP+X12-4*KeqAK*X12+power(power(SUMAXP,2)-2*SUMAXP*X12+8*KeqAK*SUMAXP*X12+power(X12,2)-4*KeqAK*power(X12,2),0.5))./((2-8*KeqAK)*KmPGKATP)).*(1+X6./KmPGKBPG+X7./KmPGKP3G));
   r11 = VmPGM./KmPGMP3G*(X7-X8./KeqPGM)./(1+X7./KmPGMP3G+X8./KmPGMP2G);
   r12 = VmENO/KmENOP2G*(X8-X9./KeqENO)./(1+X8./KmENOP2G+X9./KmENOPEP);
   r13 = VmPYK/(KmPYKPEP*KmPYKADP).*(X9.*(SUMAXP-power(power(X12,2)-4*KeqAK.*power(X12,2)-2*X12*SUMAXP+8*KeqAK*X12*SUMAXP+power(SUMAXP,2),0.5))./(1-4*KeqAK)-X10.*((X12-4*KeqAK*X12-SUMAXP+power(power(X12,2)-4*KeqAK*power(X12,2)-2*X12*SUMAXP+8*KeqAK*X12*SUMAXP+power(SUMAXP,2),0.5))./(2-8*KeqAK))./KeqPYK)./((1+X9./KmPYKPEP+X10./KmPYKPYR).*(1+(X12-4*KeqAK*X12-SUMAXP+power(power(X12,2)-4*KeqAK*power(X12,2)-2*X12*SUMAXP+8*KeqAK*X12*SUMAXP+power(SUMAXP,2),0.5))./(2-8*KeqAK)./KmPYKATP+(SUMAXP-power(power(X12,2)-4*KeqAK*power(X12,2)-2*X12*SUMAXP+8*KeqAK*X12*SUMAXP+power(SUMAXP,2),0.5))./(1-4*KeqAK)./KmPYKADP));
   r14 = VmPDC.*(power(X10,nPDC)./power(KmPDCPYR,nPDC))./(1+power(X10,nPDC)./power(KmPDCPYR,nPDC));
   r15 = -(VmADH./(KiADHNAD*KmADHETOH).*(CC14.*ETOH-X13.*X11./KeqADH)./(1+CC14./KiADHNAD+KmADHNAD*ETOH./(KiADHNAD*KmADHETOH)+KmADHNADH*X11./(KiADHNADH*KmADHACE)+X13./KiADHNADH+CC14.*ETOH./(KiADHNAD*KmADHETOH)+KmADHNADH.*CC14.*X11./(KiADHNAD*KiADHNADH*KmADHACE)+KmADHNAD*ETOH.*X13./(KiADHNAD*KmADHETOH*KiADHNADH)+X13.*X11./(KiADHNADH*KmADHACE)+CC14.*ETOH.*X11./(KiADHNAD*KmADHETOH*KiADHACE)+ETOH.*X13.*X11./(KiADHETOH*KiADHNADH*KmADHACE)));
   r16 = KSUCC.*X11;
   r17 = KATPASE.*((X12-4*KeqAK*X12-SUMAXP+power(power(X12,2)-4*KeqAK*power(X12,2)-2*X12*SUMAXP+8*KeqAK*X12*SUMAXP+power(SUMAXP,2),0.5))./(2-8*KeqAK));

   switch upper(SDETYPE)
   case 'ITO'
       driftX1 = r1 - r2;  %GLCi   % the Ito SDE drift w.r.t. X1
       diffusionX1 = sigma1;      % the Ito SDE diffusion w.r.t. X1
       derivativeX1 = 0;          % the diffusion derivative w.r.t. X1
       driftX2 = r2 - r3 - r4 - 2*r5; %G6P    % the Ito SDE drift w.r.t. X2
       diffusionX2 = sigma2;      % the Ito SDE diffusion w.r.t. X2
       derivativeX2 = 0;         % the diffusion derivative w.r.t. X2
       driftX3 = r3 - r6; %F6P   % the Ito SDE drift w.r.t. X2
       diffusionX3 = sigma3;      % the Ito SDE diffusion w.r.t. X2
       derivativeX3 = 0;         % the diffusion derivative w.r.t. X2
       driftX4 = r6 - r7;  % F16P  % the Ito SDE drift w.r.t. X2
       diffusionX4 = sigma4;      % the Ito SDE diffusion w.r.t. X2
       derivativeX4 = 0;         % the diffusion derivative w.r.t. X2

       driftX5 = 2*r7 - r8 - r9;  % TrioP  
       diffusionX5 = sigma5;      
       derivativeX5 = 0;         
       driftX6 = r9- r10 ;  % BPG  
       diffusionX6 = sigma6;      
       derivativeX6 = 0;         
       driftX7 = r10 - r11;  % P3G  
       diffusionX7 = sigma7;      
       derivativeX7 = 0;         
       driftX8 = r11 - r12;  % P2G  
       diffusionX8 = sigma8;      
       derivativeX8 = 0;         
       driftX9 = r12 - r13;  % PEP  
       diffusionX9 = sigma9;      
       derivativeX9 = 0;         

       driftX10 = r13 - r14;  % PYR  
       diffusionX10 = sigma10;      
       derivativeX10 = 0;   
       
       driftX11 = r14 - r15 - 2*r16;  % ACAL  
       diffusionX11 = sigma11;      
       derivativeX11 = 0;   
       
       driftX12 = -r2 -r4 -r5 -r6 +r10 +r13 -r17;  % P  
       diffusionX12 = sigma12;      
       derivativeX12 = 0;  
       driftX13 = -r8 + r9 -r15 +3*r16;  % NADH  
       diffusionX13 = sigma13;      
       derivativeX13 = 0; 
   case 'STRAT'
       % I have not adjusted this case. TC
   end


    out1 = zeros(1,NUMDEPVARS*NUMSIM);
    out1(1:NUMDEPVARS:end) = driftX1;
    out1(2:NUMDEPVARS:end) = driftX2;
    out1(3:NUMDEPVARS:end) = driftX3;
    out1(4:NUMDEPVARS:end) = driftX4;
    out1(5:NUMDEPVARS:end) = driftX5;
    out1(6:NUMDEPVARS:end) = driftX6;
    out1(7:NUMDEPVARS:end) = driftX7;
    out1(8:NUMDEPVARS:end) = driftX8;
    out1(9:NUMDEPVARS:end) = driftX9;
    out1(10:NUMDEPVARS:end) = driftX10;
    out1(11:NUMDEPVARS:end) = driftX11;
    out1(12:NUMDEPVARS:end) = driftX12;
    out1(13:NUMDEPVARS:end) = driftX13;
    
    out2 = zeros(1,NUMDEPVARS*NUMSIM);
    out2(1:NUMDEPVARS:end) = diffusionX1;
    out2(2:NUMDEPVARS:end) = diffusionX2;
    out2(3:NUMDEPVARS:end) = diffusionX3;
    out2(4:NUMDEPVARS:end) = diffusionX4;
    out2(5:NUMDEPVARS:end) = diffusionX5;
    out2(6:NUMDEPVARS:end) = diffusionX6;
    out2(7:NUMDEPVARS:end) = diffusionX7;
    out2(8:NUMDEPVARS:end) = diffusionX8;
    out2(9:NUMDEPVARS:end) = diffusionX9;
    out2(10:NUMDEPVARS:end) = diffusionX10;
    out2(11:NUMDEPVARS:end) = diffusionX11;
    out2(12:NUMDEPVARS:end) = diffusionX12;
    out2(13:NUMDEPVARS:end) = diffusionX13;
    
    out3 = zeros(1,NUMDEPVARS*NUMSIM);
    out3(1:NUMDEPVARS:end) = derivativeX1;
    out3(2:NUMDEPVARS:end) = derivativeX2;
    out3(3:NUMDEPVARS:end) = derivativeX3;
    out3(4:NUMDEPVARS:end) = derivativeX4;    
    out3(5:NUMDEPVARS:end) = derivativeX5;
    out3(6:NUMDEPVARS:end) = derivativeX6;
    out3(7:NUMDEPVARS:end) = derivativeX7;
    out3(8:NUMDEPVARS:end) = derivativeX8; 
    out3(9:NUMDEPVARS:end) = derivativeX9;
    out3(10:NUMDEPVARS:end) = derivativeX10;
    out3(11:NUMDEPVARS:end) = derivativeX11;
    out3(12:NUMDEPVARS:end) = derivativeX12; 
    out3(13:NUMDEPVARS:end) = derivativeX13;
    
   %:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
   %:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
   %:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
    
else
    
    switch(flag)
    case 'init'  
        out1 = t;
        
%:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::: 
%::::::::::::::::::::::  DEFINE HERE THE SDE INITAL CONDITIONS  :::::::::::::::::::::::::::::::::
%::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::

        out2 = [Xzero1 Xzero2 Xzero3 Xzero4 Xzero5 Xzero6 Xzero7 Xzero8 Xzero9 Xzero10 Xzero11 Xzero12 Xzero13];   % write here the SDE initial condition(s)
        
%:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::: 
%:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::: :::::::::::::::::::::::::::::::::
%::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
        
        out3 = [];
        
        
    otherwise
        error(['Unknown flag ''' flag '''.']);
    end
end

